AUTH_ENDPOINT = "/api-token-auth/"
TEAM_ENDPOINT = "/account/teams/"
VALIDATE_CONSUMER_REQUEST_ENDPOINT = "/orcabase/requests/validate/"
SUBMIT_CONSUMER_REQUEST_ENDPOINT = "/orcabase/requests/submit/"

RETRY_TIMES = 1  # number of times request will be retried

